# -*- rpm-spec -*-

# Note: This spec file is largely shared with the public virtio-win drivers
# shipped on fedora sites. The canonical location is here:
#
# https://github.com/crobinso/virtio-win-pkg-scripts
#
# If you make any changes to this file that affect the RPM content (but not
# version numbers or changelogs, etc), submit a patch them to the upstream
# spec file.

%global virtio_win_prewhql_build virtio-win-prewhql-0.1-134
%global qemu_ga_win_build qemu-ga-win-7.3.2-1
%global qxl_build qxl-win-unsigned-0.1-24
# qxlwddm is fedora only for now
%global qxlwddm_build spice-qxl-wddm-dod-0.16-0

Summary: VirtIO para-virtualized drivers for Windows(R)
Name: virtio-win
Version: 0.1.134
Release: 1
Group: Applications/System
URL: http://www.redhat.com/
BuildArch: noarch

%if 0%{?rhel}
# RHEL RPM ships WHQL signed drivers, which are under a proprietary license
# qemu-ga builds are GPLv2
License: Red Hat Proprietary and GPLv2
%else
# virtio-win: https://github.com/virtio-win/kvm-guest-drivers-windows/blob/master/LICENSE
# qxl: http://cgit.freedesktop.org/spice/win32/qxl/tree/xddm/COPYING
# qxldod: https://github.com/vrozenfe/qxl-dod/blob/master/LICENSE
# qemu-ga: http://git.qemu.org/?p=qemu.git;a=blob;f=COPYING
License: GPLv2
%endif

# Already built files
Source1: %{name}-%{version}-bin-for-rpm.tar.gz
Source2: %{qemu_ga_win_build}-installers.zip

# Source files shipped in the srpm
Source3: %{virtio_win_prewhql_build}-sources.zip
Source4: %{qemu_ga_win_build}-sources.zip
Source5: %{qxl_build}-sources.zip
%if 0%{?fedora}
Source6: %{qxlwddm_build}-sources.zip
%endif

BuildRequires: /usr/bin/mkisofs


%description
VirtIO para-virtualized Windows(R) drivers for 32-bit and 64-bit
Windows(R) guests.


%prep
%setup -q -T -b 1 -n %{name}-%{version}
%setup -q -T -a 2 -n %{name}-%{version} -D


%build
%{__mv} %{qemu_ga_win_build} guest-agent

# Generate .iso
/usr/bin/mkisofs -m vfddrivers -o %{name}-%{version}.iso -r -J \
  -input-charset iso8859-1 -V "%{name}-%{version}" .


%install
%{__install} -d -m0755 %{buildroot}%{_datadir}/%{name}

# Install .iso, create non-versioned symlink
%{__install} -p -m0644 %{name}-%{version}.iso %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}.iso %{buildroot}%{_datadir}/%{name}/%{name}.iso

# Install .vfd files, create non-versioned symlinks
%{__install} -p -m0644 %{name}-%{version}_x86.vfd  %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}_x86.vfd %{buildroot}%{_datadir}/%{name}/%{name}_x86.vfd
%{__install} -p -m0644 %{name}-%{version}_amd64.vfd  %{buildroot}%{_datadir}/%{name}
%{__ln_s} %{name}-%{version}_amd64.vfd %{buildroot}%{_datadir}/%{name}/%{name}_amd64.vfd

%{__cp} -a vfddrivers %{buildroot}/%{_datadir}/%{name}/drivers
%{__cp} -a guest-agent %{buildroot}/%{_datadir}/%{name}


%files
%doc virtio-win_license.txt
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/%{name}-%{version}.iso
%{_datadir}/%{name}/%{name}.iso
%{_datadir}/%{name}/*.vfd
%{_datadir}/%{name}/drivers
%{_datadir}/%{name}/guest-agent


%changelog
* Mon Mar 20 2017 Cole Robinson <crobinso@redhat.com> - 0.1.134-1
- Update to virtio-win-prewhql-0.1-134
- BZ#1429807 - [virtio-win][whql][netkvm] guests bsod(d1) when running job "NDISTest 6.0 - [1 Machine] - 1c_FaultHandling"

* Mon Mar 13 2017 Cole Robinson <crobinso@redhat.com> - 0.1.133-2
- Add .dll for vioinput on 2k12* (issue #10)

* Wed Mar 01 2017 Cole Robinson <crobinso@redhat.com> - 0.1.133-1
- Update to virtio-win-prewhql-0.1-133
- Update to spice-qxl-wddm-dod-0.16-0
- BZ#1303510 - Change the copyright on all the Windows drivers to "2017" in virtio-win-prewhql build
- NetKVM: Implement VIRTIO_NET_F_GUEST_ANNOUNCE feature
- NetKVM: Make miniportShutdown return immediately on "NdisShutdownBugCheck"

* Wed Feb 22 2017 Cole Robinson <crobinso@redhat.com> - 0.1.132-1
- Update to virtio-win-prewhql-0.1-132
- Update to qxlwddm-0.15-0
- Winxp viostor driver is no longer being updated, will remain locked at the 0.1.130 version
- Winxp qxl driver is no longer being updated, will remain locked at the spice-space 0.1.18 version
- BZ#1369353 - [balloon] backport available memory stat support
- BZ#1419785 - [virtio-win][whql][balloon] Guest WIN8-32 occured BSOD in job "DF - PNP Stop (Rebalance) Device Test (Certification)"
- pvpanic: Add IOCTL_GET_CRASH_DUMP_HEADER
- vioinput: Use viohidkmdf.sys instead of mshidkmdf.sys
- BZ#1403550 - [RFE] viostor.sys Add multi-queue support

* Mon Jan 16 2017 Cole Robinson <crobinso@redhat.com> - 0.1.130-1
- Update to virtio-win-prewhql-0.1-130
- BZ#1389445: VirtIO definition of bool as int used by all drivers that use VirtIO library, except (currently) netkvm which is C++ and uses bool as fundamental C++ type.
- BZ#1389125: viostor - extend viostor driver with STORAGE_REQUEST_BLOCK support
- BZ#1395790 - vioscsi.sys BSOD when adding CPU to live Windows Server 2012R2 guest
- BZ#1410964 - 4K virtual drives broken on Windows
- NetKVM Return correct info for OID_TCP_OFFLOAD_PARAMETERS
- Balloon: Fix blnsvr race conditions
- NetKvm: Support WMI commands
- NetKvm: Use fewer virtio receive SG descriptors
- NetKvm: Fix race of changing of RSS parameters and TX
- virtiolib: Fix uninitialized variable in VirtIOWdfFinalizeFeatures
- NetKVM: Fix 1c_IOCTLCoverage test failure
- NetKVM: Fix RX kick timing
- vioscsi: Fix verifier and debug spew due to worker exiting with affinity set. By default the workers have no affinity. We set it to the specific cpu, but KeSetSystemAffinityThreadEx returns 0, as there was no affinity. You still have to KeSetSystemAffinityThreadEx before you exit and reset it back to 0.
- balloon: Fix completion-cancellation races
- netkvm: Optimize checksum routine on 64-bit

* Fri Sep 30 2016 Cole Robinson <crobinso@redhat.com> - 0.1.126-2
- Ship .dll files for vioinput driver

* Tue Sep 27 2016 Cole Robinson <crobinso@redhat.com> - 0.1.126-1
- Update to virtio-win-prewhql-0.1-126
- Add virtio-input drivers
- NetKVM fix SDV problems
- Debug targets
- Enable RSC in INF file
- Enable dynamic RSC offload based on QEMU implementation
- Use new RSC information fields in virtio_net_hdr_v1
- Add RSC related definitions based on virtio 1.0 spec to virtio_net.h
- Sync with Win10 branch
- Many bug fixes

* Thu Jun 16 2016 Cole Robinson <crobinso@redhat.com> - 0.1.118-2
- Update to qemu-ga-win-7.3.2-1

* Mon Jun 06 2016 Cole Robinson <crobinso@redhat.com> - 0.1.118-1
- Update to virtio-win-prewhql-0.1-118
- BZ#1293249: Fix IOCTL_GET_INFORMATION regression
- Enable RSC
- Fix IPv6 offload support with SLIRP
- Fix MPE HCK test problems

* Sun Apr 10 2016 Cole Robinson <crobinso@redhat.com> - 0.1.117-1
- Update to virtio-win-prewhql-0.1-117
- Bug 1321903 [vioscsi]  Windows 10 Installer stuck at Getting files ready for installation with Virtio SCSI
- Trying out the new build system.
- vioserial - code rework and cleanup
- general - switching signing back to SHA-1

* Mon Feb 29 2016 Cole Robinson <crobinso@redhat.com> - 0.1.113-1
- Update to virtio-win-prewhql-0.1-113
- Put win10 drivers on the .vfd images
- BZ 1303510: [virtio-win] Change the copyright on all the Windows drivers to "2016" in virtio-win-prewhql build
- BZ 1122364: [vioserial] Complete pending write request on port removal
- BZ 1296099: [vioserial] Fix race in read cancellation logic
- BZ 1293249: [vioserial] Fix IOCTL_GET_INFORMATION,

* Fri Dec 18 2015 Cole Robinson <crobinso@redhat.com> - 0.1.112-1
- Update to virtio-win-prewhql-0.1-112
- BZ 1284769: [viostor] Windows XP installer stucks installing with virtio-drivers
- BZ 1245957: [viostor] [WHQL][viostor][data-plane]it could not generate dump file on WIN2008-32/64 via WLK while running Crash Dump job
- BZ 1289406: [vioser] Cannot install vioser driver successfully

* Wed Sep 23 2015 Cole Robinson <crobinso@redhat.com> - 0.1.110-2
- Update to qxl-win-unsigned-0.1-24

* Tue Sep 22 2015 Cole Robinson <crobinso@redhat.com> - 0.1.110-1
- Update to virtio-win-prewhql-0.1-110
- BZ 1223426 NetKVM Fix for performance degradation with multi-queue
- BZ 1227164 viostor/vioscsi is not digital signed by Redhat

* Sun Aug 30 2015 Cole Robinson <crobinso@redhat.com> - 0.1.109-2
- Update to qemu-ga-win-7.2.1-1

* Mon Aug 10 2015 Cole Robinson <crobinso@redhat.com> - 0.1.109-1
- Update to virtio-win-prewhql-0.1-109
- Bz 1250854 [vioscsi]The job named crash dump failed on windows 2008 -32/64 platform

* Sun Aug 09 2015 Cole Robinson <crobinso@redhat.com> - 0.1.108-1
- Update to virtio-win-prewhql-0.1-108
- BZ 1183423#c10 Change the copyright on all the Windows drivers to "2015" in virtio-win-prewhql build
- BZ 1248977 - [virtio-win][vioscsi] Cannot install vioscsi driver on win7-32&win2008-32 with build107
- BZ 1234751 [virtio-win][vioscsi]win2012R2 guest bsod(d1) when whql test DPWLK-HotAdd(1104) job
- BZ 1234741 [virtio-win][vioscsi]win2012 guest bsod(c9) when whql test DPWLK-HotAdd(1104) job
- BZ 1234507 vioserial crash due to completing a cancellable request

* Sun Aug 09 2015 Cole Robinson <crobinso@redhat.com> - 0.1.106-1
- Update to virtio-win-prewhql-0.1-106
- Update to qxl-win-unsigned-0.1-22
- Update to qxlwddm-0.1-12
- BZ 1237024  NetKVM Fix payload length calculation in IPv6 header
- BZ 1183423  Change the copyright on all the Windows drivers to "2015" in virtio-win-prewhql build
- BZ 1243229  [virtio-win][scsi][windows 10]win10 and win2016 guests bsod with D1 when run job "Bus Reset Test"
- BZ 1228967  [virtio-win][whql][viostor]job "Flush Test" failed on all guests with build 105

* Thu Jun 04 2015 Cole Robinson <crobinso@redhat.com> - 0.1.105-1
- Update to virtio-win-prewhql-0.1-105
- BZ 1223426 NetKVM Fix for performance degradation with multi-queue
- BZ 1227164 viostor/vioscsi is not digital signed by Redhat

* Mon May 25 2015 Cole Robinson <crobinso@redhat.com> - 0.1.104-1
- Update to virtio-win-prewhql-0.1-104
- BZ 1214568 vioscsi Add WMI facility to check the virito-scsi mq enabled
- BZ 1172920 vioser  bsod on shutdown after device was unplugged
- BZ 954183  NetKVM  Clean-up SDV run results during clean.bat execution
- BZ 1067249 balloon device can't be removed when service is running
- BZ 1190960 NetKVM  [mq]job failed due to "Received some net buffer lists out of order" w/ 4 queues
- BZ 1067225 viostor Windows guest performing out-of-bounds accesses on virtio device
- BZ 1195487 viostor Windows guest performing out-of-bounds accesses on virtio device


* Tue May 05 2015 Cole Robinson <crobinso@redhat.com> - 0.1.103-2
- Distribute the pre-release pvpanic driver
- Distribute the pre-release qxlwddm/qxldod driver
- Distribute qemupciserial.cat

* Fri May 01 2015 Cole Robinson <crobinso@redhat.com> - 0.1.103-1
- Update to virtio-win-prewhql-0.1-103
- BZ 1210166 vioscsi - Add multiqueue support to Windows virtio-scsi driver.
- BZ 954183  NetKVM - Static driver verifier fails with NetKVM
- BZ 1190960 NetKVM - job failed due to "Received some net buffer lists out of order" w/ 4 queues
- BZ 1190968 NetKVM - job "NDISTest 6.0 - [1 Machine] - 1c_Mini6RSSOids" last for hours and never stop w/ 4 queues
- BZ 996479  pvpanic - RFE:pvpanic driver for windows guest
- pvpanic driver isn't shipped yet since it has barely been tested
- Reduce .iso and RPM size by hardlinking identical files (bz 1217644)
- Ship QXL on the .iso (bz 1217642)

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.102-1
- Update to virtio-win-prewhql-0.1-102

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.101-1
- Update to virtio-win-prewhql-0.1-101

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.100-1
- Update to virtio-win-prewhql-0.1-100

* Sun Apr 26 2015 Cole Robinson <crobinso@redhat.com> - 0.1.96-1
- Update to virtio-win-prewhql-0.1-96
